@@ -26,7 +26,7 @@ DAY_START_MINUTE = 0
 DAY_END_HOUR = 18
 DAY_END_MINUTE = 0
 
-VERSION = '0.2.7'
+VERSION = '0.2.9'
 
 try:
         import pygtk
@@ -308,37 +308,32 @@ class _Thread(threading.Thread, _IdleObject):
                               e.start_datetime = dateFromGoogle(value,1)
                             else:
                               e.start_datetime = dateFromGoogle(value,2)
-                              e.start_datetime.hour = 0
-                              e.start_datetime.minute = 0
+                              e = e.start_datetime.replace(hour=0,minute=0)
                           elif 'DTEND' in line:
                             value = line.split(':')[1]
                             if 'T' in value:
                               e.end_datetime = dateFromGoogle(value,1)
                             else:
                               e.end_datetime = dateFromGoogle(value,2)
-                              e.start_datetime.hour = 23
-                              e.start_datetime.minute = 59
-                          if "UNTIL" in line:
-                            line = line.replace('RRULE:FREQ=','')
-                            line = line.replace('UNTIL=','')
-                            line = line.replace('INTERVAL=','')
-                            print line
-                            if len(line.split(';'))>2:
-                              frequency,until,value = line.split(';')
-                            else:
-                              frequency,until = line.split(';')
-                              value = '1'
-                            if value.isdigit():
-                              e.repeat_number = int(value)
-                            else:
-                              if 'BYMONTHDAY' in value:
-                                frequency,value=('Month(s)',1)
-
-                            if 'T' in until:
-                              e.repeat_until = dateFromGoogle(until,1)
-                            else:
-                              e.repeat_until = dateFromGoogle(until,2)
-                            e.setFrequencyFromGoogle(frequency)
+                              e.start_datetime.replace(hour=23,minute=59)
+                          if "RRULE" in line:
+                            print 'line 320:'+line
+                            line = line.replace('RRULE:','')
+                            lines = line.split(';')
+                            e.repeat_number = 1
+                            for value in lines:
+                              if "FREQ=" in value:
+                                value = value.replace('FREQ=','')
+                                e.setFrequencyFromGoogle(value)
+                              elif "UNTIL=" in value:
+                                value = value.replace('UNTIL=','')
+                                if 'T' in value:
+                                  e.repeat_until = dateFromGoogle(value,1)
+                                else:
+                                  e.repeat_until = dateFromGoogle(value,2)
+                              if "INTERVAL=" in value:
+                                value = value.replace('INTERVAL=','')
+                                e.repeat_number = int(value)
 
                 e.saveToDB(self)
               else:
@@ -367,6 +362,7 @@ class _Thread(threading.Thread, _IdleObject):
                   cal_client.UpdateEvent(an_event.GetEditLink().href, an_event)
                 elif google_update>e.lastup:
                   debug('update local event %s' % (uuid))
+                  print an_event
                   for a_when in an_event.when:
                     e.start_datetime = dateFromGoogle(a_when.start_time,format=4)
                     e.end_datetime = dateFromGoogle(a_when.end_time,format=5)
@@ -389,35 +385,51 @@ class _Thread(threading.Thread, _IdleObject):
                               e.start_datetime = dateFromGoogle(value,1)
                             else:
                               e.start_datetime = dateFromGoogle(value,2)
-                              e.start_datetime.hour = 0
-                              e.start_datetime.minute = 0
+                              e.start_datetime = e.start_datetime.replace(hour=0,minute=0)
                           elif 'DTEND' in line:
                             value = line.split(':')[1]
                             if 'T' in value:
                               e.end_datetime = dateFromGoogle(value,1)
-                              e.start_datetime.hour = 23
-                              e.start_datetime.minute = 59
                             else:
                               e.end_datetime = dateFromGoogle(value,2)
-                          if "UNTIL" in line:
-                            line = line.replace('RRULE:FREQ=','')
-                            line = line.replace('UNTIL=','')
-                            line = line.replace('INTERVAL=','')
-                            if len(line.split(';'))>2:
-                              frequency,until,value = line.split(';')
-                            else:
-                              frequency,until = line.split(';')
-                              value = '1'
-                            if value.isdigit():
-                              e.repeat_number = int(value)
-                            else:
-                              if 'BYMONTHDAY' in value:
-                                frequency,value=('Month(s)',1)
-                            if 'T' in until:
-                              e.repeat_until = dateFromGoogle(until,1)
-                            else:
-                              e.repeat_until = dateFromGoogle(until,2)
-                            e.setFrequencyFromGoogle(frequency)
+                              e.end_datetime = e.end_datetime.replace(hour=23,minute=59)
+                          if "RRULE" in line:
+                            print 'line 402:'+line
+                            line = line.replace('RRULE:','')
+                            lines = line.split(';')
+                            e.repeat_number = 1
+                            for value in lines:
+                              if "FREQ=" in value:
+                                value = value.replace('FREQ=','')
+                                e.setFrequencyFromGoogle(value)
+                              elif "UNTIL=" in value:
+                                value = value.replace('UNTIL=','')
+                                if 'T' in value:
+                                  e.repeat_until = dateFromGoogle(value,1)
+                                else:
+                                  e.repeat_until = dateFromGoogle(value,2)
+                              if "INTERVAL=" in value:
+                                value = value.replace('INTERVAL=','')
+                                e.repeat_number = int(value)
+#                            line = line.replace('RRULE:FREQ=','')
+#                            line = line.replace('UNTIL=','')
+#                            line = line.replace('INTERVAL=','')
+#                            if len(line.split(';'))>2:
+#                              frequency,until,value = line.split(';')
+#                            else:
+#                              frequency,until = line.split(';')
+#                              value = '1'
+#                            print 'frequency,until,value'+str(frequency),str(until)+str(value)
+#                            if value.isdigit():
+#                              e.repeat_number = int(value)
+#                            else:
+#                              if 'BYMONTHDAY' in value:
+#                                frequency,value=('Month(s)',1)
+#                            if 'T' in until:
+#                              e.repeat_until = dateFromGoogle(until,1)
+#                            else:
+#                              e.repeat_until = dateFromGoogle(until,2)
+#                            e.setFrequencyFromGoogle(frequency)
 
                   e.saveToDB(self)
                   debug(dir(an_event))
@@ -1308,7 +1320,7 @@ class mCalendar:
                     diff = datetime.timedelta(days=repeatvalue)
                     debug('repeatvalue : %s' % str(repeatvalue))
                     d = start_datetime
-                    while (d <= until) and (d <= getWeekDetails(self.view_datetime)[1]):
+                    while (d.date() <= until.date()) and (d <= getWeekDetails(self.view_datetime)[1]):
                       if d.strftime("%W")==self.view_datetime.strftime("%W"):
                         self.data.store.append((d.strftime(WEEK_VIEW_FORMAT),'',event[2],event[3]))
                       d = d+diff       
@@ -1316,19 +1328,19 @@ class mCalendar:
                   elif frequency=="Week(s)":
                     diff = datetime.timedelta(days=repeatvalue*7)
                     d = start_datetime
-                    while (d <= until) and (d <= getWeekDetails(self.view_datetime)[1]):
+                    while (d.date() <= until.date()) and (d <= getWeekDetails(self.view_datetime)[1]):
                       if d.strftime("%W")==self.view_datetime.strftime("%W"):
                         self.data.store.append((d.strftime(WEEK_VIEW_FORMAT),'',event[2],event[3],"",""))
                       d = d+diff
                   elif frequency=="Month(s)":
                     d = start_datetime
-                    while (d <= until) and (d <= getWeekDetails(self.view_datetime)[1]):
+                    while (d.date() <= until.date()) and (d <= getWeekDetails(self.view_datetime)[1]):
                       if d.strftime("%W")==self.view_datetime.strftime("%W"):
                         self.data.store.append((d.strftime(WEEK_VIEW_FORMAT),end_datetime.strftime(''),event[2],event[3],"",""))
                       d = addMonth(d,repeatvalue) 
                   elif frequency=="Year(s)":
                     d = start_datetime
-                    while (d <= until) and (d <= getWeekDetails(self.view_datetime)[1]):
+                    while (d.date() <= until.date()) and (d <= getWeekDetails(self.view_datetime)[1]):
                       if (d.strftime("%Y")==self.view_datetime.strftime("%Y")) and (d.strftime("%W")==self.view_datetime.strftime("%W")):
                         self.data.store.append((d.strftime(WEEK_VIEW_FORMAT),end_datetime.strftime(''),event[2],event[3],"",""))
                       d = addMonth(d,repeatvalue*12) 
@@ -1340,28 +1352,28 @@ class mCalendar:
                   if frequency=="Day(s)":
                     diff = datetime.timedelta(days=repeatvalue)
                     d = start_datetime
-                    while (d <= until) and (d <= endMonth(self.view_datetime)):
+                    while (d.date() <= until.date()) and (d <= endMonth(self.view_datetime)):
                       if d.strftime("%m")==self.view_datetime.strftime("%m"):
                         self.data.store.append((d.strftime(MONTH_VIEW_FORMAT),end_datetime.strftime(''),event[2],event[3],"",""))
                       d = d+diff         
                   elif frequency=="Week(s)":
                     diff = datetime.timedelta(days=repeatvalue*7)
                     d = start_datetime
-                    while (d <= until) and (d <= endMonth(self.view_datetime)):
+                    while (d.date() <= until.date()) and (d <= endMonth(self.view_datetime)):
                       if d.strftime("%m")==self.view_datetime.strftime("%m"):
                         self.data.store.append((d.strftime(MONTH_VIEW_FORMAT),end_datetime.strftime(''),event[2],event[3],"",""))
                       d = d+diff            
                   elif frequency=="Month(s)":
                     debug('test')
                     d = start_datetime
-                    while (d <= until) and (d <= endMonth(self.view_datetime)):
+                    while (d.date() <= until.date()) and (d <= endMonth(self.view_datetime)):
                       if d.strftime("%m")==self.view_datetime.strftime("%m"):
                         self.data.store.append((d.strftime(MONTH_VIEW_FORMAT),end_datetime.strftime(''),event[2],event[3],"",""))
                       d = addMonth(d,repeatvalue)                
                   elif frequency=="Year(s)":
                     debug('test')
                     d = start_datetime
-                    while (d <= until) and (d <= endMonth(self.view_datetime)):
+                    while (d.date() <= until.date()) and (d <= endMonth(self.view_datetime)):
                       if (d.strftime("%Y")==self.view_datetime.strftime("%Y")) and (d.strftime("%m")==self.view_datetime.strftime("%m")):
                         self.data.store.append((d.strftime(MONTH_VIEW_FORMAT),end_datetime.strftime(''),event[2],event[3],"",""))
                       d = addMonth(d,repeatvalue*12)    
